#
# spec file for package container-diff
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define project github.com/GoogleCloudPlatform/container-diff
Name:           container-diff
Version:        0.9.0
Release:        lp150.1.1
Summary:        Analyze and compare container images
License:        Apache-2.0
Group:          System/Management
Url:            https://github.com/GoogleCloudPlatform/container-diff
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.7
Requires:       docker
# disable stripping of binaries
%{go_nostrip}

%description
container-diff is a tool for analyzing and comparing container images.
container-diff can examine images along several different criteria, including:
- Docker Image History
- Image file system
- Apt packages
- RPM packages
- pip packages
- npm packages

These analyses can be performed on a single image, or a diff can be performed
on two images to compare.

%prep
%setup -q

%build
# We can't use symlinks here because go-list gets confused by symlinks, so we
# have to copy the source to $HOME/go and then use that as the GOPATH.
export GOPATH=$HOME/go
mkdir -pv $HOME/go/src/%{project}
rm -rf $HOME/go/src/%{project}/*
cp -avr * $HOME/go/src/%{project}
cd $HOME/go/src/%{project}

# Patch the version variable
# Build container-diff
export BUILDTAGS=""
go build -tags "$BUILDTAGS" \
         -buildmode=pie \
         -ldflags '-s -w -X %{project}/version.version=v%{version}' \
         -o bin/container-diff \
         %{project}

%check
# We can't use symlinks here because go-list gets confused by symlinks, so we
# have to copy the source to $HOME/go and then use that as the GOPATH.
export GOPATH=$HOME/go
mkdir -pv $HOME/go/src/%{project}
rm -rf $HOME/go/src/%{project}/*
cp -avr * $HOME/go/src/%{project}
cd $HOME/go/src/%{project}

# Test container-diff.  Exclude ppc64le, which has known issue with gotest.
PKG_LIST=$(go list ./... | grep -v %{project}/vendor})
%ifnarch ppc64le
go test $PKG_LIST
%endif

%install
cd $HOME/go/src/%{project}

# Binaries
install -D -m 0755 bin/container-diff %{buildroot}/%{_bindir}/container-diff

%fdupes -s %{buildroot}/%{_prefix}

%files
# Binaries
%{_bindir}/container-diff

%changelog
* Wed Apr 11 2018 vrothberg@suse.com
- Build container-diff as PIC (via `-buildmode=pie`).
- Exclude ppc64le from tests.
* Wed Apr 11 2018 vrothberg@suse.com
- Update container-diff to v0.9.0:
  * Add metadata diffing
  * Sanitize filepaths before joining to prevent filepath traversal
  * Fix appending of latest tag to tar files
  * Correctly clean up image filesystems
  * Set/unset write bit when unpacking directories out of permission scope
  * Add all docker config fields to image config
  * Sort maps before diffing to prevent flaky results
  * Correctly handle case where no image source is parsed
  * Cleanup image source directory
* Tue Mar 20 2018 vrothberg@suse.com
- Update container-diff to v0.8.0:
  * Fixed issue where remote:// prefix was not being stripped correctly
  * Allow updating env vars on MutableSource image
  * Save temp layers in cache directory instead of /tmp
  * Allow accessing and modifying MutableSource config
  * Fixed appending latest tag to images with no tag provided
  * Created default ImageSource if none is provided to prepper
* Thu Feb 22 2018 vrothberg@suse.com
- Cleanup spec file with spec-cleaner.
- Use golang-package macro to strip binaries.
- Update container-diff to v0.7.0:
  * Download remote:// images in RPMAnalyzer
  * Add support for custom formatting strings
  * Refactors to the cache and image unpacking code
  * Add Label to ConfigObject
  * Add MutableSource for basic image modifications
* Tue Jan 30 2018 vrothberg@suse.com
- Add container-diff v0.6.2: container-diff is a tool to analyze and diff
  container images.
